.. include:: ../common/unsafe.rst

Utility functions
=================

This are imported with::

    import toy_crypto.utils


All :mod:`utils` members 
----------------------------

.. automodule:: toy_crypto.utils
    :members:
    :undoc-members:
